/*
 * Copyright 1991, 1992, 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */
/*
 * configuration constants for Newton
 * Yossi Friedman, July 1988
 */


#define HEIGHT 		60. /* half of a room side, in Modeling coordinates */
#define TOLERANCE	1.005 /* tolerance for wall penetrations etc. */
#define MAX_MODELS	50 /* maximal size of models menu */



#ifdef CLOVER2

#define MAX_NPROC	32 /* upper bound on the number of processors */

#endif /* CLOVER2 */



/*
 * the file that contains the list of available models
 */
#define DEFAULT_MODEL_CATALOG "/usr/demos/data/newton/model_catalog"



#ifdef CONFIG_FILE

/*
 * the file that contains the display configuration
 */
#define DEFAULT_MODEL_CONFIG  "newton_config"
/* path relative to the directory where the model catalog file is */

#endif /* CONFIG_FILE */




/*
 * display state variables
 */

/* initially, should we draw shadows in lighted wall mode? */
#define SHADOWS_TOO_DEFAULT	1

/* initially, should the springs be drawn as well as the surfaces? */
#define SPRINGS_TOO_DEFAULT	0

/* initially, should we draw a translucent model? */
#define ALPHA_BLENDED_DEFAULT	0

/* initially, should we be in spin mode? */
#define SPIN_MODE_DEFAULT	0

/* initially, how should we draw the walls? */
/* legal values are draw_lighted_wall and draw_pinball_wall */
#define DRAW_WALL_DEFAULT	draw_lighted_wall

/* by default, how should we draw the model? */
/* legal values are draw_smooth_surfs, draw_flat_surfs and draw_springs */
#define DRAW_MODEL_DEFAULT	draw_flat_surfs

/* which should be the default mode, RGB (regular) or COLOR_MAP (Bermuda)? */
#define DEFAULT_MODE		RGB


/*
 * menu limitations
 */
#define MAX_MENU_ITEMS		20
#define MAX_MENU_ITEM_LEN	100


/*
 * geometric and physical limitations of the system
 */
#define MAX_ATOMS	300  /* maximal number of atoms in a model */
#define MAX_SPRING	1000 /* maximal number of springs in a model */
#define MAX_SURF	300  /* maximal number of surfaces in a model */
#define MAX_SURF_N	20   /* maximal number of vertices per surface */




/*
 * model lighting model
 */
#define MAX_LIGHTING_SIZE	100 /* length of lighting descriptions */

#define LIGHT_VECTOR	0.2, 0.5, 1.0	/* INTO the light source */

#define MODEL_LMODEL		\
    LMNULL

#define MODEL_LMODEL_SIZE		1

#define DEFAULT_MODEL_MATERIAL	\
    ALPHA, 0.4,			\
    AMBIENT, 0.15, 0.0, 0.15, 	\
    DIFFUSE, 0.4, 0.0, 0.4,	\
    SPECULAR, 0.0, 0.0, 0.0,	\
    SHININESS, 1.0,		\
    LMNULL

#define DEFAULT_MODEL_MATERIAL_SIZE	17

#define WALL_MATERIAL		\
    AMBIENT,  0.4, 0.4, 0.4,	\
    DIFFUSE,  0.6, 0.6, 0.6,	\
    SPECULAR, 0.1, 0.1, 0.1,	\
    SHININESS, 30.0,		\
    LMNULL

#define WALL_MATERIAL_SIZE		15

/*
 * pinball colors are linear functions of the depth; the coefficients
 * for red, green, and blue follow
 */
#define RED1	0.20
#define RED2	0.20
#define GREEN1	0.12
#define GREEN2	0.20
#define BLUE1	0.00
#define BLUE2	0.20
